window.Gleam.initSearch([{"doc":"cake_gleam_pgo","title":"cake_gleam_pgo","content":"# Adapter between `cake` and `gleam_pgo`\n\n[![Package &lt;a href=&quot;https://github.com/inoas/gleam-cake-pgo/releases&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/release/inoas/gleam-cake-gleam_pgo&quot; alt=&quot;GitHub release&quot;&gt;&lt;/a&gt; Version](https://img.shields.io/hexpm/v/cake_gleam_pgo)](https://hex.pm/packages/cake_gleam_pgo)\n[![Erlang-compatible](https://img.shields.io/badge/target-erlang-b83998)](https://www.erlang.org/)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/cake_gleam_pgo/)\n[![Discord](https://img.shields.io/discord/768594524158427167?label=discord%20chat&amp;amp;color=5865F2)](https://discord.gg/Fm8Pwmy)\n\n&lt;!--\n[![CI Test](https://github.com/inoas/gleam-cake-gleam_pgo/actions/workflows/test.yml/badge.svg?branch=main&amp;amp;event=push)](https://github.com/inoas/gleam-cake-gleam_pgo/actions/workflows/test.yml)\n--&gt;\n\n🎂[Cake](http://hex.pm/packages/cake) 🐘PostgreSQL adapter which which passes `PreparedStatement`s to the [gleam_pgo](http://hex.pm/packages/gleam_pgo) library for execution written in [Gleam](https://gleam.run/).\n\n## Installation\n\n```sh\ngleam add cake_gleam_pgo@1\n```\n\n## Example\n\nNotice: Official cake adapters re-use the cake namespace, thus you can import them like\nsuch: `import cake/adapter/postgres`.\n\n```gleam\nimport cake/adapter/postgres\nimport cake/delete as d\nimport cake/insert as i\nimport cake/select as s\nimport cake/where as w\nimport gleam/dynamic\nimport gleam/option.{None}\n\nconst postgres_database_name = &quot;my_postgres_database_name&quot;\n\npub fn main() {\n  postgres.with_connection(\n    host: &quot;localhost&quot;,\n    port: 5432,\n    username: &quot;postgres&quot;,\n    password: None,\n    database: postgres_database_name,\n    fn(db_connection) {\n      db_connection |&gt; create_table_if_not_exists_birds\n      db_connection |&gt; insert_into_table_birds\n      db_connection |&gt; select_from_table_birds\n      db_connection |&gt; delete_from_table_birds\n    }\n  )\n}\n\nfn create_table_if_not_exists_birds(db_connection) {\n  &quot;CREATE TABLE IF NOT EXISTS birds (\n    species TEXT,\n    average_weight FLOAT(8),\n    is_extinct BOOLEAN\n  );&quot;\n  |&gt; postgres.execute_raw_sql(db_connection)\n  |&gt; io.debug\n}\n\nfn insert_into_table_birds(db_connection) {\n  [\n    [i.string(&quot;Dodo&quot;), i.float(14.05), i.bool(True)] |&gt; i.row,\n    [i.string(&quot;Great auk&quot;), i.float(5.0), i.bool(True)] |&gt; i.row,\n  ]\n  |&gt; i.from_values(\n      table_name: &quot;birds&quot;,\n      columns: [\n        &quot;species&quot;, &quot;average_weight&quot;, &quot;is_extinct&quot;,\n      ]\n  )\n  |&gt; i.to_query\n  |&gt; postgres.run_write_query(dynamic.dynamic, db_connection)\n  |&gt; io.debug\n}\n\nfn select_from_table_birds(db_connection) {\n  s.new()\n  |&gt; s.from_table(&quot;table&quot;)\n  |&gt; s.selects([s.col(&quot;species&quot;)])\n  |&gt; s.to_query\n  |&gt; postgres.run_read_query(dynamic.dynamic, db_connection)\n  |&gt; io.debug\n}\n\nfn delete_from_table_birds(db_connection) {\n  d.new()\n  |&gt; d.table(&quot;birds&quot;)\n  |&gt; d.where(w.col(&quot;species&quot;) |&gt; w.eq(w.string(&quot;Dodo&quot;)))\n  |&gt; d.to_query\n  |&gt; postgres.run_write_query(dynamic.dynamic, db_connection)\n  |&gt; io.debug\n}\n```\n","url":"index.html"},{"doc":"cake_gleam_pgo","title":"cake_gleam_pgo","content":"# Changelog\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/), and this project adheres to\n[Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n&lt;!-- ## [Unreleased] --&gt;\n\n## [1.0.0] - 2024-10-19\n\n- Initial release.\n","url":"changelog.html"},{"doc":"cake/adapter/postgres","title":"execute_raw_sql","content":"pub fn execute_raw_sql(\n  sql_string sql_string: String,\n  db_connection db_connection: Connection,\n) -&gt; Result(Returned(Dynamic), QueryError)\n\nSynonyms:\ncake/adapter/postgres.execute_raw_sql\ncake/adapter/postgres execute_raw_sql","url":"cake/adapter/postgres.html#execute_raw_sql"},{"doc":"cake/adapter/postgres","title":"read_query_to_prepared_statement","content":"pub fn read_query_to_prepared_statement(\n  query query: ReadQuery,\n) -&gt; PreparedStatement\n Convert a Cake `ReadQuery` to a `PreparedStatement`.\n\nSynonyms:\ncake/adapter/postgres.read_query_to_prepared_statement\ncake/adapter/postgres read_query_to_prepared_statement","url":"cake/adapter/postgres.html#read_query_to_prepared_statement"},{"doc":"cake/adapter/postgres","title":"run_query","content":"pub fn run_query(\n  query query: CakeQuery(a),\n  decoder decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  db_connection db_connection: Connection,\n) -&gt; Result(List(a), QueryError)\n Run a Cake `CakeQuery` against an PostgreSQL database.\n\n This function is a wrapper around `run_read_query` and `run_write_query`.\n\nSynonyms:\ncake/adapter/postgres.run_query\ncake/adapter/postgres run_query","url":"cake/adapter/postgres.html#run_query"},{"doc":"cake/adapter/postgres","title":"run_read_query","content":"pub fn run_read_query(\n  query query: ReadQuery,\n  decoder decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  db_connection db_connection: Connection,\n) -&gt; Result(List(a), QueryError)\n\nSynonyms:\ncake/adapter/postgres.run_read_query\ncake/adapter/postgres run_read_query","url":"cake/adapter/postgres.html#run_read_query"},{"doc":"cake/adapter/postgres","title":"run_write_query","content":"pub fn run_write_query(\n  query query: WriteQuery(a),\n  decoder decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  db_connection db_connection: Connection,\n) -&gt; Result(List(a), QueryError)\n Run a Cake `WriteQuery` against an PostgreSQL database.\n\nSynonyms:\ncake/adapter/postgres.run_write_query\ncake/adapter/postgres run_write_query","url":"cake/adapter/postgres.html#run_write_query"},{"doc":"cake/adapter/postgres","title":"with_connection","content":"pub fn with_connection(\n  host host: String,\n  port port: Int,\n  username username: String,\n  password password: Option(String),\n  database database: String,\n  callback callback: fn(Connection) -&gt; a,\n) -&gt; a\n Connection to a PostgreSQL database.\n\n This is a thin wrapper around the `gleam_pgo` library&#39;s `Connection` type.\n\nSynonyms:\ncake/adapter/postgres.with_connection\ncake/adapter/postgres with_connection","url":"cake/adapter/postgres.html#with_connection"},{"doc":"cake/adapter/postgres","title":"write_query_to_prepared_statement","content":"pub fn write_query_to_prepared_statement(\n  query query: WriteQuery(a),\n) -&gt; PreparedStatement\n Convert a Cake `WriteQuery` to a `PreparedStatement`.\n\nSynonyms:\ncake/adapter/postgres.write_query_to_prepared_statement\ncake/adapter/postgres write_query_to_prepared_statement","url":"cake/adapter/postgres.html#write_query_to_prepared_statement"},{"doc":"cake/adapter/postgres","title":"cake/adapter/postgres","content":" 🎂Cake 🐘PostgreSQL adapter which which passes `PreparedStatement`s\n to the `gleam_pgo` library for execution.\n","url":"cake/adapter/postgres.html"},{"doc":"cake_gleam_pgo","title":"cake_gleam_pgo","content":"","url":"cake_gleam_pgo.html"}]);